# coding: utf-8

"""
    Habitat repository and authorization API

    Habitat API  # noqa: E501

    OpenAPI spec version: V0.0.1
    Contact: zives@seas.upenn.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import pennprov
from pennprov.api.default_api import DefaultApi  # noqa: E501
from pennprov.rest import ApiException


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = pennprov.api.default_api.DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_credential(self):
        """Test case for add_credential

        Adds a service credential for the user  # noqa: E501
        """
        pass

    def test_add_group(self):
        """Test case for add_group

        Adds a permissions group to an organization  # noqa: E501
        """
        pass

    def test_add_organization(self):
        """Test case for add_organization

        Adds an organization  # noqa: E501
        """
        pass

    def test_add_permission(self):
        """Test case for add_permission

        Adds a new labeled permission type  # noqa: E501
        """
        pass

    def test_add_subgroup_to_group(self):
        """Test case for add_subgroup_to_group

        Adds a subgroup to a group  # noqa: E501
        """
        pass

    def test_add_user_to_group(self):
        """Test case for add_user_to_group

        Adds a user to a group  # noqa: E501
        """
        pass

    def test_add_user_to_organization(self):
        """Test case for add_user_to_organization

        Adds a user to an organization  # noqa: E501
        """
        pass

    def test_create_new_user(self):
        """Test case for create_new_user

        Creates a new user  # noqa: E501
        """
        pass

    def test_get_group_from_id(self):
        """Test case for get_group_from_id

        Gets a group name from its integer ID  # noqa: E501
        """
        pass

    def test_get_group_id(self):
        """Test case for get_group_id

        Gets a group's ID from its name  # noqa: E501
        """
        pass

    def test_get_group_ids_for_user(self):
        """Test case for get_group_ids_for_user

        Gets the IDs of groups in which a user is directly a member  # noqa: E501
        """
        pass

    def test_get_group_permissions_on(self):
        """Test case for get_group_permissions_on

        Gets the group's permissions on an object  # noqa: E501
        """
        pass

    def test_get_groups_for_user(self):
        """Test case for get_groups_for_user

        Gets the groups in which a user is directly a member  # noqa: E501
        """
        pass

    def test_get_organization_from_id(self):
        """Test case for get_organization_from_id

        Gets an organization name from its integer ID  # noqa: E501
        """
        pass

    def test_get_organization_id(self):
        """Test case for get_organization_id

        Gets an organization ID from its name  # noqa: E501
        """
        pass

    def test_get_parent_group_ids(self):
        """Test case for get_parent_group_ids

        Gets the IDs of parent groups  # noqa: E501
        """
        pass

    def test_get_parent_groups(self):
        """Test case for get_parent_groups

        Gets the groups in which a user is directly a member  # noqa: E501
        """
        pass

    def test_get_permission_from_id(self):
        """Test case for get_permission_from_id

        Gets a permission's name from its integer ID  # noqa: E501
        """
        pass

    def test_get_permission_id(self):
        """Test case for get_permission_id

        Gets a permission's ID from its name  # noqa: E501
        """
        pass

    def test_get_token_route(self):
        """Test case for get_token_route

        Requests a new token  # noqa: E501
        """
        pass

    def test_get_user_info(self):
        """Test case for get_user_info

        Gets a user's info  # noqa: E501
        """
        pass

    def test_get_user_permissions_on(self):
        """Test case for get_user_permissions_on

        Gets the user's permissions on an object  # noqa: E501
        """
        pass

    def test_grant_group_permission_on(self):
        """Test case for grant_group_permission_on

        Grants a group a permission on an object  # noqa: E501
        """
        pass

    def test_grant_user_permission_on(self):
        """Test case for grant_user_permission_on

        Grants a user a permission on an object  # noqa: E501
        """
        pass

    def test_is_registered(self):
        """Test case for is_registered

        Returns whether a user credential is valid for a service  # noqa: E501
        """
        pass

    def test_is_valid_credential(self):
        """Test case for is_valid_credential

        Returns whether a local user credential is valid  # noqa: E501
        """
        pass

    def test_revoke_group_permission_on(self):
        """Test case for revoke_group_permission_on

        Revokes a group a permission on an object  # noqa: E501
        """
        pass

    def test_revoke_user_permission_on(self):
        """Test case for revoke_user_permission_on

        Revokes a user a permission on an object  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        Updates user properties  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Habitat repository and authorization API

    Habitat API  # noqa: E501

    OpenAPI spec version: V0.0.1
    Contact: zives@seas.upenn.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pennprov.api_client import ApiClient


class ProvenanceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_connected_from(self, token, **kwargs):  # noqa: E501
        """Get the outgoing neighbors of the given prov token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_connected_from(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param str label:
        :return: ProvTokenSetModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_connected_from_with_http_info(token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_connected_from_with_http_info(token, **kwargs)  # noqa: E501
            return data

    def get_connected_from_with_http_info(self, token, **kwargs):  # noqa: E501
        """Get the outgoing neighbors of the given prov token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_connected_from_with_http_info(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param str label:
        :return: ProvTokenSetModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token', 'label']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_connected_from" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `get_connected_from`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []
        if 'label' in params:
            query_params.append(('label', params['label']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/nodes/{token}/neighbors/out', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProvTokenSetModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_connected_to(self, token, **kwargs):  # noqa: E501
        """Get the incoming neighbors of the given prov token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_connected_to(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param str label:
        :return: ProvTokenSetModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_connected_to_with_http_info(token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_connected_to_with_http_info(token, **kwargs)  # noqa: E501
            return data

    def get_connected_to_with_http_info(self, token, **kwargs):  # noqa: E501
        """Get the incoming neighbors of the given prov token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_connected_to_with_http_info(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param str label:
        :return: ProvTokenSetModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token', 'label']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_connected_to" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `get_connected_to`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []
        if 'label' in params:
            query_params.append(('label', params['label']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/nodes/{token}/neighbors/in', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProvTokenSetModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_edges_from(self, token, **kwargs):  # noqa: E501
        """Get the outgoing edges of the given prov token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_edges_from(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param str resource:
        :return: ProvEdgeSetModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_edges_from_with_http_info(token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_edges_from_with_http_info(token, **kwargs)  # noqa: E501
            return data

    def get_edges_from_with_http_info(self, token, **kwargs):  # noqa: E501
        """Get the outgoing edges of the given prov token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_edges_from_with_http_info(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param str resource:
        :return: ProvEdgeSetModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token', 'resource']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_edges_from" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `get_edges_from`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []
        if 'resource' in params:
            query_params.append(('resource', params['resource']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/nodes/{token}/links/out', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProvEdgeSetModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_edges_to(self, token, **kwargs):  # noqa: E501
        """Get the incoming edges of the given prov token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_edges_to(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param str resource:
        :return: ProvEdgeSetModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_edges_to_with_http_info(token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_edges_to_with_http_info(token, **kwargs)  # noqa: E501
            return data

    def get_edges_to_with_http_info(self, token, **kwargs):  # noqa: E501
        """Get the incoming edges of the given prov token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_edges_to_with_http_info(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param str resource:
        :return: ProvEdgeSetModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token', 'resource']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_edges_to" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `get_edges_to`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []
        if 'resource' in params:
            query_params.append(('resource', params['resource']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/nodes/{token}/links/in', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProvEdgeSetModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_provenance_data(self, token, **kwargs):  # noqa: E501
        """Get the tuple associated with a provenance token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_provenance_data(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :return: TupleWithSchemaModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_provenance_data_with_http_info(token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_provenance_data_with_http_info(token, **kwargs)  # noqa: E501
            return data

    def get_provenance_data_with_http_info(self, token, **kwargs):  # noqa: E501
        """Get the tuple associated with a provenance token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_provenance_data_with_http_info(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :return: TupleWithSchemaModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_provenance_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `get_provenance_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/nodes/{token}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TupleWithSchemaModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_provenance_location(self, token, **kwargs):  # noqa: E501
        """Get the location of a provenance token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_provenance_location(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :return: ProvSpecifierModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_provenance_location_with_http_info(token, **kwargs)  # noqa: E501
        else:
            (data) = self.get_provenance_location_with_http_info(token, **kwargs)  # noqa: E501
            return data

    def get_provenance_location_with_http_info(self, token, **kwargs):  # noqa: E501
        """Get the location of a provenance token  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_provenance_location_with_http_info(token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :return: ProvSpecifierModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_provenance_location" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `get_provenance_location`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/nodes/{token}/location', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProvSpecifierModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_provenance_nodes(self, **kwargs):  # noqa: E501
        """Get the provenance graph&#39;s nodes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_provenance_nodes(async=True)
        >>> result = thread.get()

        :param async bool
        :param str resource:
        :return: ProvNodeMapModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.get_provenance_nodes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_provenance_nodes_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_provenance_nodes_with_http_info(self, **kwargs):  # noqa: E501
        """Get the provenance graph&#39;s nodes  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.get_provenance_nodes_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str resource:
        :return: ProvNodeMapModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resource']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_provenance_nodes" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'resource' in params:
            query_params.append(('resource', params['resource']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/nodes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ProvNodeMapModel',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_provenance_link(self, body, **kwargs):  # noqa: E501
        """Store a provenance link between tokens  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.store_provenance_link(body, async=True)
        >>> result = thread.get()

        :param async bool
        :param StoreLinkModel body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.store_provenance_link_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.store_provenance_link_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def store_provenance_link_with_http_info(self, body, **kwargs):  # noqa: E501
        """Store a provenance link between tokens  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.store_provenance_link_with_http_info(body, async=True)
        >>> result = thread.get()

        :param async bool
        :param StoreLinkModel body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_provenance_link" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `store_provenance_link`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/links', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def store_provenance_node(self, token, body, **kwargs):  # noqa: E501
        """Store a provenance token with its location  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.store_provenance_node(token, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param StoreNodeModel body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.store_provenance_node_with_http_info(token, body, **kwargs)  # noqa: E501
        else:
            (data) = self.store_provenance_node_with_http_info(token, body, **kwargs)  # noqa: E501
            return data

    def store_provenance_node_with_http_info(self, token, body, **kwargs):  # noqa: E501
        """Store a provenance token with its location  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.store_provenance_node_with_http_info(token, body, async=True)
        >>> result = thread.get()

        :param async bool
        :param str token: (required)
        :param StoreNodeModel body: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['token', 'body']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method store_provenance_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `store_provenance_node`")  # noqa: E501
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `store_provenance_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'token' in params:
            path_params['token'] = params['token']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['jwt']  # noqa: E501

        return self.api_client.call_api(
            '/provenance/nodes/{token}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Habitat repository and authorization API

    Habitat API  # noqa: E501

    OpenAPI spec version: V0.0.1
    Contact: zives@seas.upenn.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import pennprov
from pennprov.models.integer_field_model import IntegerFieldModel  # noqa: E501
from pennprov.rest import ApiException


class TestIntegerFieldModel(unittest.TestCase):
    """IntegerFieldModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testIntegerFieldModel(self):
        """Test IntegerFieldModel"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pennprov.models.integer_field_model.IntegerFieldModel()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Habitat repository and authorization API

    Habitat API  # noqa: E501

    OpenAPI spec version: V0.0.1
    Contact: zives@seas.upenn.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from pennprov.models.field_model import FieldModel
from pennprov.models.group_details import GroupDetails
from pennprov.models.id_model import IDModel
from pennprov.models.org_details import OrgDetails
from pennprov.models.prov_edge_model import ProvEdgeModel
from pennprov.models.prov_edge_set_model import ProvEdgeSetModel
from pennprov.models.prov_node_map_model import ProvNodeMapModel
from pennprov.models.prov_specifier_model import ProvSpecifierModel
from pennprov.models.prov_token_set_model import ProvTokenSetModel
from pennprov.models.response_error import ResponseError
from pennprov.models.store_link_model import StoreLinkModel
from pennprov.models.store_node_model import StoreNodeModel
from pennprov.models.tuple_with_schema_model import TupleWithSchemaModel
from pennprov.models.user_credentials import UserCredentials
from pennprov.models.user_info import UserInfo
from pennprov.models.web_token import WebToken
from pennprov.models.boolean_field_model import BooleanFieldModel
from pennprov.models.double_field_model import DoubleFieldModel
from pennprov.models.integer_field_model import IntegerFieldModel
from pennprov.models.long_field_model import LongFieldModel
from pennprov.models.prov_expression_model import ProvExpressionModel
from pennprov.models.prov_location_model import ProvLocationModel
from pennprov.models.prov_specifier_field_model import ProvSpecifierFieldModel
from pennprov.models.prov_token_field_model import ProvTokenFieldModel
from pennprov.models.prov_token_model import ProvTokenModel
from pennprov.models.string_field_model import StringFieldModel



# coding: utf-8

"""
    Habitat repository and authorization API

    Habitat API  # noqa: E501

    OpenAPI spec version: V0.0.1
    Contact: zives@seas.upenn.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import pennprov
from pennprov.api.provenance_api import ProvenanceApi  # noqa: E501
from pennprov.rest import ApiException


class TestProvenanceApi(unittest.TestCase):
    """ProvenanceApi unit test stubs"""

    def setUp(self):
        self.api = pennprov.api.provenance_api.ProvenanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_connected_from(self):
        """Test case for get_connected_from

        Get the outgoing neighbors of the given prov token  # noqa: E501
        """
        pass

    def test_get_connected_to(self):
        """Test case for get_connected_to

        Get the incoming neighbors of the given prov token  # noqa: E501
        """
        pass

    def test_get_edges_from(self):
        """Test case for get_edges_from

        Get the outgoing edges of the given prov token  # noqa: E501
        """
        pass

    def test_get_edges_to(self):
        """Test case for get_edges_to

        Get the incoming edges of the given prov token  # noqa: E501
        """
        pass

    def test_get_provenance_data(self):
        """Test case for get_provenance_data

        Get the tuple associated with a provenance token  # noqa: E501
        """
        pass

    def test_get_provenance_location(self):
        """Test case for get_provenance_location

        Get the location of a provenance token  # noqa: E501
        """
        pass

    def test_get_provenance_nodes(self):
        """Test case for get_provenance_nodes

        Get the provenance graph's nodes  # noqa: E501
        """
        pass

    def test_store_provenance_link(self):
        """Test case for store_provenance_link

        Store a provenance link between tokens  # noqa: E501
        """
        pass

    def test_store_provenance_node(self):
        """Test case for store_provenance_node

        Store a provenance token with its location  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
